from asap3 import EMT
from ase.build import bulk
from ase.md.nptberendsen import NPTBerendsen
from ase.md.npt import NPT
from ase.md.velocitydistribution import (MaxwellBoltzmannDistribution,
                                         Stationary)
import ase.units as units

import numpy as np


def run(temperature_K):
    rng = np.random.RandomState(42)

    atoms = bulk('Au', cubic=True)
    atoms *= (4, 4, 4)

    atoms.calc = EMT()

    ttime = 25 * units.fs
    ptime = 75 * units.fs

    MaxwellBoltzmannDistribution(atoms, temperature_K=temperature_K, rng=rng)
    Stationary(atoms)

    with NPT(
            atoms,
            timestep=10 * units.fs,
            ttime=ttime,
            externalstress=0.0,
            pfactor=ptime**2 * 0.6,
            temperature_K=temperature_K,
            trajectory='npt.traj',
            logfile='npt.log',
            loginterval=1000,
    ) as md:
        md.run(20000)


from ase.utils import workdir

temperatures_K = range(770, 901, 10)

for temp_K in temperatures_K:
    with workdir(f'out/npt.temp={temp_K:03d}', mkdir=True):
        run(temp_K)
